.. image:: https://img.shields.io/pypi/v/incredible.svg
   :alt: PyPi
   :target: https://pypi.python.org/pypi/incredible
.. image:: https://img.shields.io/pypi/l/incredible.svg
   :alt: BSD-3
   :target: https://opensource.org/licenses/BSD-3-Clause

=====================================================================================
incredible
=====================================================================================

A bunch of functions for finding Bayesian credible intervals and regions. Now includes some functions to make diagnostic plots for Markov chains.

It isn't exactly documentation, but a tutorials showing how to use this package can be found under "Credible Regions" and "MCMC Diagnostics" in `this course <https://kipac.github.io/StatisticalMethods/>`_. The docstrings are also fairly complete.
